@@ -24,6 +24,6 @@ from .p import P, _P
 from .r import R, _R
 from .rbp import RBP, _RBP
 from .rprec import Rprec, _Rprec
-from .rr import RR, _RR
+from .rr import RR, MRR, _RR
 from .setp import SetP, _SetP
 from .success import Success, _Success
