@@ -5,7 +5,8 @@ from .base import BaseMeasure, ParamInfo
 class _ERR(measures.BaseMeasure):
     """
     The Expected Reciprocal Rank (ERR) is a precision-focused measure.
-    TODO: finish
+    In essence, an extension of reciprocal rank that encapsulates both graded relevance and
+    a more realistic cascade-based user model of how users brwose a ranking.
     """
     __name__ = 'ERR'
     NAME = __name__
